PUBLISHED_PUBLIC_SLUGS = [
    'public-question-1',
    'public-question-2',
    'public-question-4',
    ]
PUBLISHED_MEMBER_SLUGS = [
    'members-question-1',
    'members-question-2',
    'members-question-4',
    ]
PUBLISHED_STAFF_SLUGS = [
    'staff-question-1',
    'staff-question-2',
    'staff-question-4',
    ]
TOTAL_QUESTIONS_COUNT = 12

PUBLIC_TOPIC_SLUGS = [
    'public-topic',
    'mixed-topic',
    ]
MEMBERS_TOPIC_SLUGS = [
    'public-topic',
    'members-topic',
    'staff-and-members-topic',
    'mixed-topic',
    ]
STAFF_TOPIC_SLUGS = [
    'public-topic',
    'members-topic',
    'staff-topic',
    'staff-and-members-topic',
    'mixed-topic',
    ]
TOTAL_TOPIC_COUNT = 5
